#
# spec file for package wget2
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           wget2
%define lname libwget2
Version:        2.1.0
Release:        1.3
Summary:        A Tool for Mirroring FTP and HTTP Servers
License:        GPL-3.0-or-later AND LGPL-3.0-or-later
Group:          Productivity/Networking/Web/Utilities
URL:            https://www.gnu.org/software/wget/
Source:         https://ftp.gnu.org/gnu/wget/%name-%version.tar.gz
Source2:        https://ftp.gnu.org/gnu/wget/%name-%version.tar.gz.sig
Source3:        https://savannah.gnu.org/people/viewgpg.php?user_id=87218#/%name.keyring
BuildRequires:  doxygen
BuildRequires:  flex
BuildRequires:  gettext-devel >= 0.18.1
BuildRequires:  libidn2-devel >= 0.14
BuildRequires:  libtool >= 2.2
BuildRequires:  libunistring-devel
BuildRequires:  pkg-config
BuildRequires:  pkgconfig(bzip2)
BuildRequires:  pkgconfig(gnutls)
BuildRequires:  pkgconfig(libbrotlidec)
BuildRequires:  pkgconfig(liblzma)
BuildRequires:  pkgconfig(libnghttp2)
BuildRequires:  pkgconfig(libpcre2-8)
BuildRequires:  pkgconfig(libpsl)
BuildRequires:  pkgconfig(libzstd)
BuildRequires:  pkgconfig(zlib)

%description
Wget enables you to retrieve WWW documents or FTP files from a
server. This can be done in script files or via the command line.

In many cases Wget2 downloads much faster than Wget1.x due to HTTP
zlib compression, parallel connections and use of If-Modified-Since
HTTP header. HTTP/2 has been implemented. Wget2 also consumes less
system and user CPU cycles than Wget1.x.

%package -n %lname
Summary:        A library to download and mirror FTP/HTTP sites
License:        LGPL-3.0-or-later
Group:          System/Libraries

%description -n %lname
Wget enables you to retrieve WWW documents or FTP files from a
server. This can be done in script files or via the command line.

libwget which provides an interface to many useful functions used by
Wget2.

%package devel
Summary:        Development files for libwget
License:        LGPL-3.0-or-later
Group:          Development/Libraries/C and C++
Requires:       %lname = %version-%release
Obsoletes:      libwget-devel < %version-%release
Provides:       libwget-devel = %version-%release

%description devel
libwget which provides an interface to many useful functions used by
Wget2.

This subpackage contains the header files for application wanting
to build against libwget.

%prep
%autosetup -p1

%build
#./bootstrap --no-git --gnulib-srcdir="$PWD/gnulib"
%configure --disable-static
%make_build

%check
%make_build check

%install
%make_install
rm -f "%buildroot/%_bindir"/*_noinstall "%buildroot/%_libdir"/*.la
%find_lang %name

%post   -n %lname -p /sbin/ldconfig
%postun -n %lname -p /sbin/ldconfig

%files -f %name.lang
%_bindir/wget*
%license COPYING

%files -n %lname
%_libdir/libwget*.so.*
%license COPYING.LESSER

%files devel
%_mandir/man3/*.3*
%_libdir/pkgconfig/*.pc
%_libdir/libwget*.so
%_includedir/wget*

%changelog
* Fri Sep  1 2023 Jan Engelhardt <jengelh@inai.de>
- Update to release 2.1.0
  * New option --follow-sitemaps
  * New option --dane (cert validation via DNS)
  * Implement --check-certificate=quiet
  * Support proxies on non-default ports
  * Added CIDR support for no_proxy (IPv4 and IPv6)
  * Add decoding of numeric XML entities
  * Support compilation of wget.h from C++
  * Handle comments in robots.txt correctly
* Sat Jun  4 2022 Dirk Müller <dmueller@suse.com>
- update to 2.0.1:
  * Fix escaping space in query part
  * Set EXIT_STATUS_NETWORK on error for the last try
  * Fix -k/--convert-links fragment
  * Fix escapng URLs with -k/--convert-links
  * Fix false reporting of a PSL error
  * Fix --directory-prefix with --content-disposition
  * Allow spaces and \ escaping in passwords in .netrc
  * Fix download abortion on some versions of Windows
  * Fix --unlink behavior
  * Fix deflate decompression when server omits the header
  * WolfSSL: Fix buffer overflow in SHA512 hashing
  * WolfSSL: Fix memory leak
  * Add support for unquoted HTML attribute values
  * OpenSSL: Fix several OCSP issues
  * Use keep-alive for HTTP/1.1 and higher as default
  * Don't create core dumps on CTRL-c
  * Fix replacing Content-Type: headers
  * Fix NULL pointer read / segfault
  * Fix several build issues
  * Fix several documentation issues
* Sat Feb 26 2022 Andreas Stieger <andreas.stieger@gmx.de>
- add upstream signing key and validate source signature
* Sun Sep 26 2021 Jan Engelhardt <jengelh@inai.de>
- Update to release 2.0.0
- Drop test-buffer-printf.patch, test-dl.patch (no longer applies)
* Tue Apr 14 2020 Andreas Schwab <schwab@suse.de>
- test-dl.patch, test-buffer-printf.patch: Fix undefined behviour in
  testsuite
* Sat Sep  7 2019 Jan Engelhardt <jengelh@inai.de>
- Update to beta release 1.99.2
  * Add new option --keep-extension, --retry-on-http-status,
  - -dns-cache-preload, -X/--exclude-directories,
  - I/--include-directories, --save-content-on, --limit-rate,
  - -unlink, --start-pos, --no-if-modified-since, --ocsp-server,
  - -ocsp-nonce, --ocsp-date
  * Add zstd decompression (RFC8478)
  * Add TLSv1_x to --secure-protocol
  * Add support for TCP FastOpen Linux 4.11+ style
  * Add basic HTML entity decoding (RFC1866)
  * Add TLS 1.3 post-handshake authentication
  * Skip -np/--no-parent for CSS URLs
* Fri Oct 21 2016 jengelh@inai.de
- Initial package for build.opensuse.org (1.0~855)
